ui_reveal library

Classes

CircularRevealEffect
Circular reveal effect centered at transition origin.
DiagonalWipeRevealEffect
Diagonal wipe transition that uncovers new content along a diagonal.
FadeRevealEffect
Fade transition effect for reveal snapshots.
LiquidWaveRevealEffect
Wipe reveal with a fluid sine-wave leading edge.
RevealConfig
Configuration for reveal transition timing.
RevealController
Orchestrates reveal transitions for an attached RevealHost.
RevealEffect
Strategy interface for rendering reveal overlays.
RevealEffectContext
Rendering data for a single reveal frame.
RevealEffects
Built-in reveal effects namespace.
RevealHost
Hosts reveal transitions above child.
RevealScope
High-level reveal entrypoint that hosts RevealHost and controller.
SlideRevealEffect
Slide transition effect that wipes old content away in slideDirection.

Enums

DiagonalWipeDirection
Supported diagonal wipe directions.
RevealDirection
Direction of reveal transition.

Extensions

BuildContextRevealExtension on BuildContext
Utilities for reveal transition geometry.